Learn R Programming

mde (version 0.3.3)

na_counts: Get NA counts for a given character, numeric, factor, etc.

Description

Get NA counts for a given character, numeric, factor, etc.

Usage

na_counts(x)

Arguments

x

A vector whose number of missing values is to be determined.

Examples

Run this code
na_counts(airquality$Ozone) 

Run the code above in your browser using DataLab