powered by
Get NA counts for a given character, numeric, factor, etc.
na_counts(x)
A vector whose number of missing values is to be determined.
na_counts(airquality$Ozone)
Run the code above in your browser using DataLab